wrap_in_paren_ref

Function wrap_in_paren_ref 

pub fn wrap_in_paren_ref(expr: &Expr) -> Expr
Wraps a reference to an expression in a ParenExpr with DUMMY_SP span. This clones the expression and is commonly used when creating error contexts.

Example

let wrapped = wrap_in_paren_ref(&path);